﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Net;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Animation;
using System.Windows.Shapes;
using Telerik.Windows.Controls;

namespace SilverlightApplication3
{
	public class DropDownButtonWithValidation : RadDropDownButton
	{
		public static readonly DependencyProperty IsValidProperty =
			DependencyProperty.Register("IsValid", typeof(bool), typeof(DropDownButtonWithValidation), new PropertyMetadata(true, OnIsValidPropertyChanged));

		public bool IsValid
		{
			get { return (bool)GetValue(IsValidProperty); }
			set { SetValue(IsValidProperty, value); }
		}

		public DropDownButtonWithValidation()
		{
			this.DefaultStyleKey = typeof(DropDownButtonWithValidation);
		}

		private static void OnIsValidPropertyChanged(object sender, DependencyPropertyChangedEventArgs args)
		{
			var button = sender as DropDownButtonWithValidation;
			if (button != null)
			{
				button.GoToValidationStates((bool)args.NewValue);
			}
		}

		protected override void OnGotFocus(RoutedEventArgs e)
		{
			base.OnGotFocus(e);
			if (!this.IsValid)
			{
				VisualStateManager.GoToState(this, "Invalid", false);
			}
		}

		protected override void OnLostFocus(RoutedEventArgs e)
		{
			base.OnLostFocus(e);

			if (!this.IsValid)
			{
				VisualStateManager.GoToState(this, "InvalidUnfocused", false);
			}
		}

		private void GoToValidationStates(bool isValid)
		{
			if (isValid)
			{
				VisualStateManager.GoToState(this, "Valid", false);
			}
			else
			{
				if (this.IsFocused)
				{
					VisualStateManager.GoToState(this, "Invalid", false);
				}
				else
				{
					VisualStateManager.GoToState(this, "InvalidUnfocused", false);
				}
			}
		}
	}
}
